# portfolio-manager

A simple tool for tracking and analysing the performance of investment portfolios.

## Features and Usage

This package provides the user with the functionality to make deposits and withdrawals 
of funds into one or more investment portfolios. The overall value of the portfolios 
can be updated over time based on the market value of the underlying assets, and these 
transactions are logged and saved.

The package also contains various methods for calculating the rate of return of the 
user’s portfolios. These methods include a simple percentage return calculator and a 
more sophisticated time-weighted return calculator.

Example usage of the package can be found in the Jupyter Notebooks within 
portfolio-manager/notebooks, in the GitHub repo (link below).

## Installation

The source code is currently hosted on GitHub at:
https://github.com/J-Curwell/portfolio-manager

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/portfolio-manager/).

```sh
# PyPI
pip install portfolio-manager
```

## License

MIT license
